@@ -20,7 +20,7 @@
 #' @param pandoc_args arguments passed to the pandoc_args argument of rmarkdown \code{\link[rmarkdown]{html_document}}
 #' @param md_extensions arguments passed to the md_extensions argument of rmarkdown \code{\link[rmarkdown]{html_document}}
 #' @param toc_depth adjust table of contents depth
-#' @param embed_fonts if TRUE, use local files for fonts used in the template. This leads to bigger files but ensures that these fonts are available.
+#' @param embed_fonts if TRUE, use local files for fonts used in the template. This leads to bigger files but ensures that these fonts are available. If FALSE they are downloaded from Google Web Fonts.
 #' @param use_bookdown if TRUE, uses \code{\link[bookdown]{html_document2}} instead of \code{\link[rmarkdown]{html_document}}, thus providing numbered sections and cross references
 #' @param mathjax set to NULL to disable Mathjax insertion
 #' @param ... Additional function arguments passed to R Markdown \code{\link[rmarkdown]{html_document}}
@@ -73,7 +73,11 @@ readthedown <- function(fig_width = 8,
 # readthedown js and css
 html_dependency_readthedown <- function(embed_fonts = TRUE) {
   stylesheets <- "readthedown.css"
-  if (embed_fonts) stylesheets <- c(stylesheets, "readthedown_fonts.css")
+  if (embed_fonts) {
+    stylesheets <- c(stylesheets, "readthedown_fonts_embed.css")
+  } else {
+    stylesheets <- c(stylesheets, "readthedown_fonts_download.css")
+  }
   htmltools::htmlDependency(name = "readthedown",
                  version = "0.1",
                  src = system.file("templates/readthedown", package = "rmdformats"),
